summaryrefslogtreecommitdiffstats
path: root/kmymoney2/mymoney/mymoneypayee.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/mymoney/mymoneypayee.h')
-rw-r--r--kmymoney2/mymoney/mymoneypayee.h106
1 files changed, 53 insertions, 53 deletions
diff --git a/kmymoney2/mymoney/mymoneypayee.h b/kmymoney2/mymoney/mymoneypayee.h
index c2c711b..b1d2fce 100644
--- a/kmymoney2/mymoney/mymoneypayee.h
+++ b/kmymoney2/mymoney/mymoneypayee.h
@@ -26,8 +26,8 @@
// ----------------------------------------------------------------------------
// QT Includes
-#include <qstring.h>
-class QStringList;
+#include <tqstring.h>
+class TQStringList;
// ----------------------------------------------------------------------------
// Project Includes
@@ -46,14 +46,14 @@ class KMYMONEY_EXPORT MyMoneyPayee : public MyMoneyObject
{
private:
// Simple fields
- QString m_name;
- QString m_address;
- QString m_city;
- QString m_state;
- QString m_postcode;
- QString m_telephone;
- QString m_email;
- QString m_notes;
+ TQString m_name;
+ TQString m_address;
+ TQString m_city;
+ TQString m_state;
+ TQString m_postcode;
+ TQString m_telephone;
+ TQString m_email;
+ TQString m_notes;
// Transaction matching fields
bool m_matchingEnabled; //< Whether this payee should be matched at all
@@ -64,10 +64,10 @@ private:
* Semicolon separated list of matching keys used when trying to find a suitable
* payee for imported transactions.
*/
- QString m_matchKey;
+ TQString m_matchKey;
// Category (account) matching fields
- QString m_defaultAccountId;
+ TQString m_defaultAccountId;
/**
* This member keeps a reference to an external database
@@ -78,7 +78,7 @@ private:
* If no external database is available it should be kept
* empty by the application.
*/
- QString m_reference;
+ TQString m_reference;
public:
typedef enum {
@@ -88,48 +88,48 @@ public:
} payeeMatchType;
MyMoneyPayee();
- MyMoneyPayee(const QString& id, const MyMoneyPayee& payee);
- MyMoneyPayee(const QString& name,
- const QString& address=QString::null,
- const QString& city=QString::null,
- const QString& state=QString::null,
- const QString& postcode=QString::null,
- const QString& telephone=QString::null,
- const QString& email=QString::null);
+ MyMoneyPayee(const TQString& id, const MyMoneyPayee& payee);
+ MyMoneyPayee(const TQString& name,
+ const TQString& address=TQString(),
+ const TQString& city=TQString(),
+ const TQString& state=TQString(),
+ const TQString& postcode=TQString(),
+ const TQString& telephone=TQString(),
+ const TQString& email=TQString());
/**
* This is the constructor for a payee that is described by a
- * QDomElement (e.g. from a file).
+ * TQDomElement (e.g. from a file).
*
* @param el const reference to the QDomElement from which to
* create the object
*/
- MyMoneyPayee(const QDomElement& el);
+ MyMoneyPayee(const TQDomElement& el);
~MyMoneyPayee();
// Simple get operations
- QString name(void) const { return m_name; }
- QString address(void) const { return m_address; }
- QString city(void) const { return m_city; }
- QString state(void) const { return m_state; }
- QString postcode(void) const { return m_postcode; }
- QString telephone(void) const { return m_telephone; }
- QString email(void) const { return m_email; }
- QString notes(void) const { return m_notes; }
-
- const QString id(void) const { return m_id; };
- const QString reference(void) const { return m_reference; };
+ TQString name(void) const { return m_name; }
+ TQString address(void) const { return m_address; }
+ TQString city(void) const { return m_city; }
+ TQString state(void) const { return m_state; }
+ TQString postcode(void) const { return m_postcode; }
+ TQString telephone(void) const { return m_telephone; }
+ TQString email(void) const { return m_email; }
+ TQString notes(void) const { return m_notes; }
+
+ const TQString id(void) const { return m_id; };
+ const TQString reference(void) const { return m_reference; };
// Simple set operations
- void setName(const QString& val) { m_name = val; }
- void setAddress(const QString& val) { m_address = val; }
- void setCity(const QString& val) { m_city = val; }
- void setState(const QString& val) { m_state = val; }
- void setPostcode(const QString& val) { m_postcode = val; }
- void setTelephone(const QString& val) { m_telephone = val; }
- void setEmail(const QString& val) { m_email = val; }
- void setNotes(const QString& val) { m_notes = val; }
- void setReference(const QString& ref) { m_reference = ref; }
+ void setName(const TQString& val) { m_name = val; }
+ void setAddress(const TQString& val) { m_address = val; }
+ void setCity(const TQString& val) { m_city = val; }
+ void setState(const TQString& val) { m_state = val; }
+ void setPostcode(const TQString& val) { m_postcode = val; }
+ void setTelephone(const TQString& val) { m_telephone = val; }
+ void setEmail(const TQString& val) { m_email = val; }
+ void setNotes(const TQString& val) { m_notes = val; }
+ void setReference(const TQString& ref) { m_reference = ref; }
/**
* Get all match data in one call
@@ -140,7 +140,7 @@ public:
*
* @return the matching type (see payeeMatchType for details)
*/
- payeeMatchType matchData(bool& ignorecase, QStringList& keys) const;
+ payeeMatchType matchData(bool& ignorecase, TQStringList& keys) const;
/**
* Set all match data in one call
@@ -149,7 +149,7 @@ public:
* @param ignorecase Whether case should be ignored for the key/name match
* @param keys A list of keys themselves, if applicable
*/
- void setMatchData(payeeMatchType type, bool ignorecase, const QStringList& keys);
+ void setMatchData(payeeMatchType type, bool ignorecase, const TQStringList& keys);
/**
* Get all match data in one call (overloaded version for database module)
@@ -160,7 +160,7 @@ public:
*
* @return the matching type (see payeeMatchType for details)
*/
- payeeMatchType matchData(bool& ignorecase, QString& keyString) const;
+ payeeMatchType matchData(bool& ignorecase, TQString& keyString) const;
/**
* Set all match data in one call (overloaded version for database module)
@@ -169,12 +169,12 @@ public:
* @param ignorecase Whether case should be ignored for the key/name match
* @param keys A list of keys in single-string format, if applicable
*/
- void setMatchData(payeeMatchType type, bool ignorecase, const QString& keys);
+ void setMatchData(payeeMatchType type, bool ignorecase, const TQString& keys);
bool defaultAccountEnabled() const { return !m_defaultAccountId.isEmpty(); }
- const QString& defaultAccountId() const { return m_defaultAccountId; }
- void setDefaultAccountId(const QString& id = QString()) {
+ const TQString& defaultAccountId() const { return m_defaultAccountId; }
+ void setDefaultAccountId(const TQString& id = TQString()) {
m_defaultAccountId = id;
}
@@ -184,7 +184,7 @@ public:
// Equality operator
bool operator == (const MyMoneyPayee &) const;
- void writeXML(QDomDocument& document, QDomElement& parent) const;
+ void writeXML(TQDomDocument& document, TQDomElement& tqparent) const;
/**
* This method checks if a reference to the given object exists. It returns,
@@ -195,12 +195,12 @@ public:
* @retval true This object references object with id @p id.
* @retval false This object does not reference the object with id @p id.
*/
- virtual bool hasReferenceTo(const QString& id) const;
+ virtual bool hasReferenceTo(const TQString& id) const;
static MyMoneyPayee null;
};
-inline bool operator==(const MyMoneyPayee& lhs, const QString& rhs) { return lhs.id() == rhs; }
+inline bool operator==(const MyMoneyPayee& lhs, const TQString& rhs) { return lhs.id() == rhs; }
#endif
// vim:cin:si:ai:et:ts=2:sw=2:
@@ -88,48 +88,48 @@ public:
*
- * @param el const reference to the QDomElement from which to
+ * @param el const reference to the TQDomElement from which to
* create the object
*/